==> gradle-8.9-1.src.tar.zst: gradle-8.9/src/dependency-management/org/gradle/api/internal/artifacts/ivyservice/resolveengine/artifact/ResolvedVariantCache.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact;

import org.gradle.internal.service.scopes.Scope;
import org.gradle.internal.service.scopes.ServiceScope;

import java.util.function.Function;

import static org.gradle.internal.component.model.VariantResolveMetadata.Identifier;

/**
 * Cache for ResolvedVariant instances.
 *
 * This cache contains ResolvedVariants for the entire build.
 */
@ServiceScope(Scope.Build.class)
public interface ResolvedVariantCache {
    /**
     * Caches resolved variants created by the given function if the identifier is eligible for caching.
     *
     * @param key key for the cache
     * @param mappingFunction function to create a {@link ResolvedVariant}
     * @return the resolved variant created by the function or a cached instance, if available
     */
    ResolvedVariant computeIfAbsent(Identifier key, Function<? super Identifier, ? extends ResolvedVariant> mappingFunction);
}

==> gradle-8.10.1-1.src.tar.zst: gradle-8.10.1/src/dependency-management/org/gradle/api/internal/artifacts/ivyservice/resolveengine/artifact/ResolvedVariantCache.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact;

import org.gradle.internal.service.scopes.Scope;
import org.gradle.internal.service.scopes.ServiceScope;

import java.util.function.Function;

/**
 * Cache for ResolvedVariant instances.
 *
 * This cache contains ResolvedVariants for the entire build.
 */
@ServiceScope(Scope.Build.class)
public interface ResolvedVariantCache {
    /**
     * Caches resolved variants created by the given function if the identifier is eligible for caching.
     *
     * @param key key for the cache
     * @param mappingFunction function to create a {@link ResolvedVariant}
     * @return the resolved variant created by the function or a cached instance, if available
     */
    ResolvedVariant computeIfAbsent(CacheKey key, Function<? super CacheKey, ? extends ResolvedVariant> mappingFunction);

    /**
     * An identifier of a variant in this cache.
     */
    interface CacheKey {}
}
